===============================================
``serializers``: Serializing bibliographic data
===============================================

.. automodule:: relaton.serializers

.. contents::
   :local:

``bibxml``: BibXML element tree
===============================

.. automodule:: relaton.serializers.bibxml
   :members:
   :undoc-members:
   :show-inheritance:

Abstracts
---------

.. automodule:: relaton.serializers.bibxml.abstracts
   :members:
   :undoc-members:
   :show-inheritance:

Anchors
-------

.. automodule:: relaton.serializers.bibxml.anchor
   :members:
   :undoc-members:
   :show-inheritance:

Authors
-------

.. automodule:: relaton.serializers.bibxml.authors
   :members:
   :undoc-members:
   :show-inheritance:

References
----------

.. automodule:: relaton.serializers.bibxml.reference
   :members:
   :undoc-members:
   :show-inheritance:

Series
------

.. automodule:: relaton.serializers.bibxml.series
   :members:
   :undoc-members:
   :ignore-module-all:
   :exclude-members: DOCID_SERIES_EXTRACTORS
   :show-inheritance:

.. autodata:: relaton.serializers.bibxml.series.DOCID_SERIES_EXTRACTORS
   :annotation: = [...]

Targets
-------

.. automodule:: relaton.serializers.bibxml.target
   :members:
   :undoc-members:
   :show-inheritance:


``bibxml_string``: BibXML string
================================

.. automodule:: relaton.serializers.bibxml_string
   :members:
   :undoc-members:
   :show-inheritance:
